@@ -1,8 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*-
  *
- * Portions derived from xscreensaver,
- * Copyright (c) 1991-2004 Jamie Zawinski <jwz@jwz.org>
- * 
  * Copyright (C) 2004-2005 William Jon McCann <mccann@jhu.edu>
  *
  * This program is free software; you can redistribute it and/or
@@ -33,9 +30,6 @@
 #include <sys/wait.h>
 
 #include <glib/gi18n.h>
-#define DBUS_API_SUBJECT_TO_CHANGE
-#include <dbus/dbus.h>
-#include <dbus/dbus-glib.h>
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h>
 
@@ -50,6 +44,7 @@
 static gboolean verbose       = FALSE;
 static gboolean show_version  = FALSE;
 static gboolean enable_logout = FALSE;
+static gboolean enable_switch = FALSE;
 
 static GOptionEntry entries [] = {
         { "verbose", 0, 0, G_OPTION_ARG_NONE, &verbose,
@@ -132,6 +127,10 @@ popup_dialog_idle (void)
                 g_object_set (widget, "logout-enabled", TRUE, NULL);
         }
 
+        if (enable_switch) {
+                g_object_set (widget, "switch-enabled", TRUE, NULL);
+        }
+
         g_signal_connect (GS_LOCK_PLUG (widget), "response", G_CALLBACK (response_cb), NULL);
 
         gtk_widget_show (widget);
@@ -141,7 +140,12 @@ popup_dialog_idle (void)
         return FALSE;
 }
 
-/* Initializations that potentially take place as a priveleged user:
+
+/*
+ * Copyright (c) 1991-2004 Jamie Zawinski <jwz@jwz.org>
+ * Copyright (c) 2005 William Jon McCann <mccann@jhu.edu>
+ *
+ * Initializations that potentially take place as a priveleged user:
    If the xscreensaver executable is setuid root, then these initializations
    are run as root, before discarding privileges.
 */
@@ -176,7 +180,11 @@ privileged_initialization (int     *argc,
 }
 
 
-/* Figure out what locking mechanisms are supported.
+/*
+ * Copyright (c) 1991-2004 Jamie Zawinski <jwz@jwz.org>
+ * Copyright (c) 2005 William Jon McCann <mccann@jhu.edu>
+ *
+ * Figure out what locking mechanisms are supported.
  */
 static gboolean
 lock_initialization (int     *argc,
@@ -272,6 +280,10 @@ main (int    argc,
                 exit (1);
         }
 
+#ifdef HAVE_USER_SWITCHING
+        enable_switch = TRUE;
+#endif
+
         if (show_version) {
                 g_print ("%s %s\n", argv [0], VERSION);
                 exit (1);
