@@ -191,6 +191,21 @@ gs_job_get_theme_path (GSJob *job,
         }
 }
 
+void
+gs_job_append_theme_path (GSJob      *job,
+                          const char *path)
+{
+        g_return_if_fail (GS_IS_JOB (job));
+        g_return_if_fail (path != NULL);
+
+        job->priv->search_path_len++;
+        job->priv->search_path = g_renew (char *, job->priv->search_path, job->priv->search_path_len);
+
+        job->priv->search_path [job->priv->search_path_len - 1] = g_strdup (path);
+
+        /*do_theme_change (job);*/
+}
+
 void
 gs_job_prepend_theme_path (GSJob      *job,
                            const char *path)
@@ -547,6 +562,11 @@ gs_job_init (GSJob *job)
         i = 0;
         job->priv->search_path [i++] = g_strdup (THEMESDIR);
 
+#ifdef XSCREENSAVER_CONFIG_DIR
+        if (g_file_test (XSCREENSAVER_CONFIG_DIR, G_FILE_TEST_IS_DIR))
+                gs_job_append_theme_path (job, XSCREENSAVER_CONFIG_DIR);
+#endif
+
         job->priv->themes_valid = FALSE;
 }
 
